v0.3.1 (2024-12-01)
-------------------
- Migrated from setuptools to hatch
- Drop support for Python 3.7
- Support Python 3.13

v0.3.0 (2023-10-30)
-------------------
- Support Python 3.10, 3.11, and 3.12
- Drop support for Python 3.6
- Update pydantic to v2.0
- Update outgoing minimum version to 0.6

v0.2.1 (2021-03-31)
-------------------
- BCC headers are now removed from e-mails before submitting to Mailgun, which
  does not remove BCC's itself

v0.2.0 (2021-03-14)
-------------------
- Added logging

v0.1.0 (2021-03-08)
-------------------
Initial release
